==> gengmei_flutter_plugin-0.0.2.tar.gz: android/src/main/kotlin/com/example/gengmei_flutter_plugin/ImagePlugin/repository/ImageRespository.kt <==
package com.example.myimagepicker.repository

import android.content.Context
import android.util.Log
import com.example.myimagepicker.bean.MediaFile
import com.example.myimagepicker.bean.MediaFolder
import com.example.myimagepicker.repository.local.ImageScanner
import io.reactivex.Observable
import io.reactivex.ObservableOnSubscribe
import io.reactivex.android.schedulers.AndroidSchedulers
import io.reactivex.disposables.CompositeDisposable
import io.reactivex.schedulers.Schedulers
import java.util.*
import kotlin.collections.ArrayList
import kotlin.collections.HashMap

/**
 * Created by lsy
 * on 2019/3/27
 */
class ImageRespository {

    private var isShowCamera: Boolean = false
    private lateinit var disposable: CompositeDisposable
    private var mMediaFileList = ArrayList<MediaFile>()
    private var mMediaFolderList = ArrayList<MediaFolder>()
    private val mSelectImagePaths = ArrayList<String>()
    private val mSelectImageMedita = ArrayList<MediaFile>()
    private var orList = Collections.synchronizedList(ArrayList<String>())

    var maxCount = 0
    var isOr = false

    fun scanPhoneVideo(context: Context) {
        //TODO
    }


    fun scanPhoneImage(context: Context): Observable<HashMap<String, ArrayList<HashMap<String, Any>>>> {
        return Observable.create(ObservableOnSubscribe<HashMap<String, ArrayList<HashMap<String, Any>>>> {
            val imageScanner = ImageScanner(context)
            val imageList = imageScanner.queryMedia()
            val imageListMap = ArrayList<HashMap<String, Any>>();
            imageList.forEach {
                val itemMap = HashMap<String, Any>()
                it.folderName?.run {
                    itemMap.put("folderName", this)
                }
                it.path?.run {
                    itemMap.put("path", this)
                }
                it.size?.run {
                    itemMap.put("size", this)
                }
                imageListMap.add(itemMap);
            }
//            imageList.clear();

            val finalList = HashMap<String, ArrayList<HashMap<String, Any>>>(imageList.size)
            imageListMap.forEach {
                it["folderName"]?.run {
                    Log.e("lsy", "it  ${this}")
                    if (finalList[this] == null) {
                        finalList[this as String] = ArrayList<HashMap<String, Any>>()
                        finalList[this]!!.add(it);
                    } else {
                        finalList[this as String]!!.add(it);
                    }
                }
            }
            finalList["gengmei_all_Image_jiamijiamijiami"] = imageListMap;
            it.onNext(finalList)
        }).subscribeOn(Schedulers.computation()).observeOn(AndroidSchedulers.mainThread())
    }

    fun updateList(list: List<MediaFile>) {
        mMediaFileList.clear()
        mMediaFileList.addAll(list)
    }

    fun cacheFolder(list: List<MediaFolder>) {
        mMediaFolderList.clear()
        mMediaFolderList.addAll(list)
    }

    fun quit() {
        disposable.dispose()
        disposable.clear()
    }

    fun getList(): ArrayList<MediaFile> {
        return mMediaFileList
    }

    fun getCache(): ArrayList<MediaFolder> {
        return mMediaFolderList
    }

    val selectPaths: ArrayList<String>
        get() = mSelectImagePaths

    val isCanChoose: Boolean
        get() = if (selectPaths.size < maxCount) {
            true
        } else false

    fun addImageToSelectList(mediaFile: MediaFile, pos: Int): Boolean {
        if (mSelectImagePaths.contains(mediaFile.path)) {
            mSelectImageMedita.remove(mediaFile)
            return mSelectImagePaths.remove(mediaFile.path)
        } else {
            return if (mSelectImagePaths.size < maxCount) {
                mSelectImageMedita.add(mediaFile)
                mSelectImagePaths.add(mediaFile.path!!)
            } else {
                false
            }
        }
    }

    fun addImagePathsToSelectList(imagePaths: List<String>) {
        for (i in imagePaths.indices) {
            val imagePath = imagePaths[i]
            if (!mSelectImagePaths.contains(imagePath) && mSelectImagePaths.size < maxCount) {
                mSelectImagePaths.add(imagePath)
            }
        }
    }

    fun isImageSelect(imagePath: String): Boolean {
        return if (mSelectImagePaths.contains(imagePath)) {
            true
        } else {
            false
        }
    }

    fun removeAll() {
        mMediaFileList.clear()
        mSelectImagePaths.clear()
    }

    fun clearCache() {
        isOr = false
        mMediaFolderList.clear()
        mSelectImageMedita.clear()
        orList.clear()
    }

    fun onlyGetChoosedList(): ArrayList<MediaFile> {
        var list = ArrayList<MediaFile>()
        for (i in mSelectImagePaths) {
            for (item in mSelectImageMedita) {
                if (item.path.equals(i)) {
                    list.add(item)
                    break
                }
            }
        }
        return list
    }

    fun addCaptureImage(path: String) {
        mMediaFolderList.get(0).mediaFileList?.add(0, MediaFile(path))
    }


    fun findIsOr(path: String): Boolean {
        for (item in orList) {
            if (item.equals(path)) {
                return true
            }
        }
        return false
    }

    fun addImageToOrList(imagePath: String): Boolean {
        if (orList.contains(imagePath)) {
            return orList.remove(imagePath)
        } else {
            return if (orList.size < maxCount) {
                orList.add(imagePath)
            } else {
                false
            }
        }
    }

    companion object {
        private var instance: ImageRespository? = null
        const val TAG: String = "Image_Picker"

        fun getInstance(): ImageRespository {
            if (instance == null) {
                synchronized(ImageRespository::class.java) {
                    if (instance == null) {
                        instance = ImageRespository();
                    }
                }
            }
            return instance!!
        }
    }
}

==> gengmei_flutter_plugin-0.0.5.tar.gz: android/src/main/kotlin/com/example/gengmei_flutter_plugin/ImagePlugin/repository/ImageRespository.kt <==
package com.example.myimagepicker.repository

import android.content.Context
import android.util.Log
import com.example.myimagepicker.bean.MediaFile
import com.example.myimagepicker.bean.MediaFolder
import com.example.myimagepicker.repository.local.ImageScanner
import io.reactivex.Observable
import io.reactivex.ObservableOnSubscribe
import io.reactivex.android.schedulers.AndroidSchedulers
import io.reactivex.disposables.CompositeDisposable
import io.reactivex.schedulers.Schedulers
import java.util.*
import kotlin.collections.ArrayList
import kotlin.collections.HashMap

/**
 * Created by lsy
 * on 2019/3/27
 */
class ImageRespository {

    private var isShowCamera: Boolean = false
    private lateinit var disposable: CompositeDisposable
    private var mMediaFileList = ArrayList<MediaFile>()
    private var mMediaFolderList = ArrayList<MediaFolder>()
    private val mSelectImagePaths = ArrayList<String>()
    private val mSelectImageMedita = ArrayList<MediaFile>()
    private var orList = Collections.synchronizedList(ArrayList<String>())

    var maxCount = 0
    var isOr = false

    fun scanPhoneVideo(context: Context) {
        //TODO
    }


    fun scanPhoneImage(context: Context): Observable<HashMap<String, ArrayList<HashMap<String, Any>>>> {
        return Observable.create(ObservableOnSubscribe<HashMap<String, ArrayList<HashMap<String, Any>>>> {
            val imageScanner = ImageScanner(context)
            val imageList = imageScanner.queryMedia()
            val imageListMap = ArrayList<HashMap<String, Any>>();
            imageList.forEach {
                val itemMap = HashMap<String, Any>()
                it.folderName?.run {
                    itemMap.put("folderName", this)
                }
                it.path?.run {
                    itemMap.put("path", this)
                }
                it.size?.run {
                    itemMap.put("size", this)
                }
                imageListMap.add(itemMap);
            }
//            imageList.clear();

            val finalList = HashMap<String, ArrayList<HashMap<String, Any>>>(imageList.size)
            imageListMap.forEach {
                it["folderName"]?.run {
                    Log.e("lsy", "it  ${this}")
                    if (finalList[this] == null) {
                        finalList[this as String] = ArrayList<HashMap<String, Any>>()
                        finalList[this]!!.add(it);
                    } else {
                        finalList[this as String]!!.add(it);
                    }
                }
            }
            finalList["IsGengmeiAlbumAllImages"] = imageListMap;
            it.onNext(finalList)
        }).subscribeOn(Schedulers.computation()).observeOn(AndroidSchedulers.mainThread())
    }

    fun updateList(list: List<MediaFile>) {
        mMediaFileList.clear()
        mMediaFileList.addAll(list)
    }

    fun cacheFolder(list: List<MediaFolder>) {
        mMediaFolderList.clear()
        mMediaFolderList.addAll(list)
    }

    fun quit() {
        disposable.dispose()
        disposable.clear()
    }

    fun getList(): ArrayList<MediaFile> {
        return mMediaFileList
    }

    fun getCache(): ArrayList<MediaFolder> {
        return mMediaFolderList
    }

    val selectPaths: ArrayList<String>
        get() = mSelectImagePaths

    val isCanChoose: Boolean
        get() = if (selectPaths.size < maxCount) {
            true
        } else false

    fun addImageToSelectList(mediaFile: MediaFile, pos: Int): Boolean {
        if (mSelectImagePaths.contains(mediaFile.path)) {
            mSelectImageMedita.remove(mediaFile)
            return mSelectImagePaths.remove(mediaFile.path)
        } else {
            return if (mSelectImagePaths.size < maxCount) {
                mSelectImageMedita.add(mediaFile)
                mSelectImagePaths.add(mediaFile.path!!)
            } else {
                false
            }
        }
    }

    fun addImagePathsToSelectList(imagePaths: List<String>) {
        for (i in imagePaths.indices) {
            val imagePath = imagePaths[i]
            if (!mSelectImagePaths.contains(imagePath) && mSelectImagePaths.size < maxCount) {
                mSelectImagePaths.add(imagePath)
            }
        }
    }

    fun isImageSelect(imagePath: String): Boolean {
        return if (mSelectImagePaths.contains(imagePath)) {
            true
        } else {
            false
        }
    }

    fun removeAll() {
        mMediaFileList.clear()
        mSelectImagePaths.clear()
    }

    fun clearCache() {
        isOr = false
        mMediaFolderList.clear()
        mSelectImageMedita.clear()
        orList.clear()
    }

    fun onlyGetChoosedList(): ArrayList<MediaFile> {
        var list = ArrayList<MediaFile>()
        for (i in mSelectImagePaths) {
            for (item in mSelectImageMedita) {
                if (item.path.equals(i)) {
                    list.add(item)
                    break
                }
            }
        }
        return list
    }

    fun addCaptureImage(path: String) {
        mMediaFolderList.get(0).mediaFileList?.add(0, MediaFile(path))
    }


    fun findIsOr(path: String): Boolean {
        for (item in orList) {
            if (item.equals(path)) {
                return true
            }
        }
        return false
    }

    fun addImageToOrList(imagePath: String): Boolean {
        if (orList.contains(imagePath)) {
            return orList.remove(imagePath)
        } else {
            return if (orList.size < maxCount) {
                orList.add(imagePath)
            } else {
                false
            }
        }
    }

    companion object {
        private var instance: ImageRespository? = null
        const val TAG: String = "Image_Picker"

        fun getInstance(): ImageRespository {
            if (instance == null) {
                synchronized(ImageRespository::class.java) {
                    if (instance == null) {
                        instance = ImageRespository();
                    }
                }
            }
            return instance!!
        }
    }
}
